/*
 *  Copyright (C) 2002  Alex Krist - KR1ST
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Please make sure that before using this software that you are authorized
 *  by the appropriate authorities in your country to use this software.
 */

#include "Cybiko.h"
#include "../jed1.0/jed.h"
#include "main.h"

/* Main module handle. */
struct module_t main_module;

/* Boolean to determine program exit. */
bool exit_power;

/* Form for the main screen. */
Jed *main_form;
Jed_item *main_txt1;
Jed_item *main_txt2;
Jed_item *main_txt3;
Jed_item *main_txt4;
Jed_item *main_power;
Jed_item *main_exit;
Jed_item *main_ji;


long main(int argc, char* argv[], bool start)
{
    /* Initialize this application. */
    init_module(&main_module);

    exit_power = FALSE;

    /* Set up the main screen. */
    jed_open(&main_form, &main_module, NULL);
    jed_text_new(&main_txt1, main_form,   0, 0, 160,  14, "UI Power (c) KR1ST", mini_bold_font);
    jed_button_new(&main_power, main_form, 30,   42, 100,  16, "Power Up/Down", mini_bold_font);
    jed_button_new(&main_exit, main_form, 30,   60, 100,  16, "Exit", mini_bold_font);

    /* Indicate power setting on screen.*/
    if (get_power())
    {
        jed_text_new(&main_txt2, main_form,   50, 80, 0,  0, "Power: HIGH", cool_normal_font);
    }
    else
    {
        jed_text_new(&main_txt2, main_form,   50, 80, 0,  0, "Power: low", cool_normal_font);
    }

    /* Add some help. */
    jed_text_new(&main_txt3, main_form,   13, 20, 0,  0, "Power Up/Down -> toggle power", mini_normal_font);
    jed_text_new(&main_txt4, main_form,   13, 30, 0,  0, "Exit -> Exit Application", mini_normal_font);

    while(!exit_power)
    {
        /* Draw screen and wait for any action to take place. */
        jed_main(main_form, &main_ji, 0);

        /* Exit if Exit-button or Escape key is pressed. */
        if((main_ji == NILL)
           ||
           (main_ji == main_exit))
        {
            exit_power = TRUE;
        }
        else
        {
            /* Power Toggle button is pressed. */
            if (main_ji == main_power)
            {
                /* Toggle the power level. */
                set_power(!get_power());

                /* Indicate new power level on screen. */
                jed_destroy_item(main_txt2);
                if (get_power())
                {
                    jed_text_new(&main_txt2, main_form,   50, 80, 0,  0, "Power: HIGH", cool_normal_font);
                }
                else
                {
                    jed_text_new(&main_txt2, main_form,   50, 80, 0,  0, "Power: low", cool_normal_font);
                }
            }
        }
    }
 
    jed_close(main_form);

    return 0;
}


/* Standard user supplied Jed message handler. */
Jed_rc jed_process_message(Jed *jed, struct Message *message)
{
    char line[31];

    bool message_done;

    message_done = TRUE;

    switch(message->msgid)
    {
        case MSG_SHUTUP:
        case MSG_QUIT:
            exit_power = TRUE;
            break;
        default:
            message_done = FALSE;
    }

    /* If message is handled by us, then return 1, else 0. */
    if(message_done)
    {
        return 1;
    }
    else
    {
        return 0;
    }
}


